[xorg-commit-diffs]
xc/programs/Xserver/hw/xwin XWin.rc, 1.1.4.1.2.9,
1.1.4.1.2.10 windialogs.c, 1.1.6.7, 1.1.6.8 winresource.h,
1.1.2.5, 1.1.2.6 wintrayicon.c, 1.1.6.7, 1.1.6.8
Harold L Hunt II
xorg-commit at pdx.freedesktop.org
Sun Mar 28 19:47:40 PST 2004
- Previous message: [xorg-commit-diffs] xc/programs/Xserver/hw/xwin InitOutput.c,
1.1.4.1.6.1, 1.1.4.1.6.1.4.1 XWin.man, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 XWin.rc, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 ddraw.h,
1.1.10.1, 1.1.10.1.4.1 obj_base.h, 1.1.10.1,
1.1.10.1.4.1 winconfig.c, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 winconfig.h, 1.1.10.1, 1.1.10.1.4.1 winkeybd.h,
1.1.10.1, 1.1.10.1.4.1 winshaddd.c, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 wintrayicon.c, 1.1.10.1,
1.1.10.1.4.1 winvideo.c, 1.1.10.1, 1.1.10.1.4.1 winwindow.h,
1.1.4.1.6.1, 1.1.4.1.6.1.4.1
- Next message: [xorg-commit-diffs] xc/programs/xterm resize.man, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 xterm.man, 1.1.4.3.4.1.4.1, 1.1.4.3.4.1.4.2
- Messages sorted by:
[ date ]
[ thread ]
[ subject ]
[ author ]
Committed by: harold
Update of /cvs/xorg/xc/programs/Xserver/hw/xwin
In directory pdx:/tmp/cvs-serv32194
Modified Files:
Tag: CYGWIN
XWin.rc windialogs.c winresource.h wintrayicon.c
Log Message:
Fix problem with tray menu in non-multi-window modes, add framework for Takuma to display the number of connected clients on shutdown.
Index: XWin.rc
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/XWin.rc,v
retrieving revision 1.1.4.1.2.9
retrieving revision 1.1.4.1.2.10
diff -u -d -r1.1.4.1.2.9 -r1.1.4.1.2.10
--- a/XWin.rc 27 Mar 2004 19:54:22 -0000 1.1.4.1.2.9
+++ b/XWin.rc 28 Mar 2004 17:49:32 -0000 1.1.4.1.2.10
@@ -72,15 +72,16 @@
/* Exit */
-EXIT_DIALOG DIALOG DISCARDABLE 32, 32, 180, 70
+EXIT_DIALOG DIALOG DISCARDABLE 32, 32, 180, 78
STYLE WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_VISIBLE | WS_TABSTOP | DS_CENTER
FONT 8, "MS Sans Serif"
CAPTION "Cygwin/X - Exit?"
BEGIN
- PUSHBUTTON "E&xit", IDOK, 55, 48, 30, 14
- DEFPUSHBUTTON "&Cancel", IDCANCEL, 95, 48, 30, 14
+ PUSHBUTTON "E&xit", IDOK, 55, 56, 30, 14
+ DEFPUSHBUTTON "&Cancel", IDCANCEL, 95, 56, 30, 14
CTEXT "Exiting will close all screens running on this display.", IDC_STATIC, 7, 12, 166, 8
- CTEXT "Proceed with shutdown of this display/server?", IDC_STATIC, 7, 24, 166, 8
+ CTEXT "No information about connected clients available.", IDC_CLIENTS_CONNECTED, 7, 24, 166, 8
+ CTEXT "Proceed with shutdown of this display/server?", IDC_STATIC, 7, 36, 166, 8
END
Index: winresource.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/Attic/winresource.h,v
retrieving revision 1.1.2.5
retrieving revision 1.1.2.6
diff -u -d -r1.1.2.5 -r1.1.2.6
--- a/winresource.h 26 Mar 2004 20:39:17 -0000 1.1.2.5
+++ b/winresource.h 28 Mar 2004 17:49:32 -0000 1.1.2.6
@@ -41,10 +41,13 @@
#define IDI_XWIN 101
#define IDI_XWIN_BOXED 102
#define IDM_TRAYICON_MENU 103
-#define ID_APP_EXIT 104
-#define ID_APP_HIDE_ROOT 105
-#define ID_APP_ALWAYS_ON_TOP 106
-#define ID_APP_ABOUT 107
+#define IDC_CLIENTS_CONNECTED 104
+
+
+#define ID_APP_EXIT 200
+#define ID_APP_HIDE_ROOT 201
+#define ID_APP_ALWAYS_ON_TOP 202
+#define ID_APP_ABOUT 203
#define ID_ABOUT_UG 300
#define ID_ABOUT_FAQ 301
Index: wintrayicon.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/wintrayicon.c,v
retrieving revision 1.1.6.7
retrieving revision 1.1.6.8
diff -u -d -r1.1.6.7 -r1.1.6.8
--- a/wintrayicon.c 19 Mar 2004 13:21:19 -0000 1.1.6.7
+++ b/wintrayicon.c 28 Mar 2004 17:49:32 -0000 1.1.6.8
@@ -161,20 +161,10 @@
else
#endif
{
- /* Remove Show Root Window button */
- RemoveMenu (hmenuTray,
- ID_APP_HIDE_ROOT,
- MF_BYCOMMAND);
-
/* Remove Hide Root Window button */
RemoveMenu (hmenuTray,
ID_APP_HIDE_ROOT,
MF_BYCOMMAND);
-
- /* Remove separator */
- RemoveMenu (hmenuTray,
- 0,
- MF_BYPOSITION);
}
SetupRootMenu ((unsigned long)hmenuTray);
- Previous message: [xorg-commit-diffs] xc/programs/Xserver/hw/xwin InitOutput.c,
1.1.4.1.6.1, 1.1.4.1.6.1.4.1 XWin.man, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 XWin.rc, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 ddraw.h,
1.1.10.1, 1.1.10.1.4.1 obj_base.h, 1.1.10.1,
1.1.10.1.4.1 winconfig.c, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 winconfig.h, 1.1.10.1, 1.1.10.1.4.1 winkeybd.h,
1.1.10.1, 1.1.10.1.4.1 winshaddd.c, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 wintrayicon.c, 1.1.10.1,
1.1.10.1.4.1 winvideo.c, 1.1.10.1, 1.1.10.1.4.1 winwindow.h,
1.1.4.1.6.1, 1.1.4.1.6.1.4.1
- Next message: [xorg-commit-diffs] xc/programs/xterm resize.man, 1.1.4.1.6.1,
1.1.4.1.6.1.4.1 xterm.man, 1.1.4.3.4.1.4.1, 1.1.4.3.4.1.4.2
- Messages sorted by:
[ date ]
[ thread ]
[ subject ]
[ author ]
More information about the xorg-commit-diffs
mailing list
Index: windialogs.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/windialogs.c,v
retrieving revision 1.1.6.7
retrieving revision 1.1.6.8
diff -u -d -r1.1.6.7 -r1.1.6.8
--- a/windialogs.c 27 Mar 2004 06:49:07 -0000 1.1.6.7
+++ b/windialogs.c 28 Mar 2004 17:49:32 -0000 1.1.6.8
@@ -242,6 +242,8 @@
(int) GetDlgItem (g_hDlgExit, IDCANCEL), TRUE);
}
+#define CONNECTED_CLIENTS_FORMAT "There are currently %d clients connected."
+
/*
* Exit dialog window procedure
@@ -259,18 +261,41 @@
switch (message)
{
case WM_INITDIALOG:
- /* Store pointers to private structures for future use */
- s_pScreenPriv = (winPrivScreenPtr) lParam;
- s_pScreenInfo = s_pScreenPriv->pScreenInfo;
- s_pScreen = s_pScreenInfo->pScreen;
+ {
+ char *pszConnectedClients;
+ int iReturn;
+ int iConnectedClients = 100;
- winCenterDialog (hDialog);
+ /* Store pointers to private structures for future use */
+ s_pScreenPriv = (winPrivScreenPtr) lParam;
+ s_pScreenInfo = s_pScreenPriv->pScreenInfo;
+ s_pScreen = s_pScreenInfo->pScreen;
+
+ winCenterDialog (hDialog);
+
+ /* Set icon to standard app icon */
+ PostMessage (hDialog,
+ WM_SETICON,
+ ICON_SMALL,
+ (LPARAM) LoadIcon (g_hInstance,
+ MAKEINTRESOURCE(IDI_XWIN)));
- /* Set icon to standard app icon */
- PostMessage (hDialog,
- WM_SETICON,
- ICON_SMALL,
- (LPARAM) LoadIcon (g_hInstance, MAKEINTRESOURCE(IDI_XWIN)));
+ /* Format the connected clients string */
+ iReturn = sprintf (NULL, CONNECTED_CLIENTS_FORMAT,
+ iConnectedClients);
+ if (iReturn <= 0)
+ return TRUE;
+ pszConnectedClients = malloc (iReturn + 1);
+ if (!pszConnectedClients)
+ return TRUE;
+ snprintf (pszConnectedClients, iReturn + 1, CONNECTED_CLIENTS_FORMAT,
+ iConnectedClients);
+
+ /* Set the number of connected clients */
+ SetWindowText (GetDlgItem (hDialog, IDC_CLIENTS_CONNECTED),
+ pszConnectedClients);
+ free (pszConnectedClients);
+ }
return TRUE;
case WM_COMMAND: